window.Gleam.initSearch([{"doc":"gleastsq","title":"gleastsq","content":"# gleastsq\n\n[![Package Version](https://img.shields.io/hexpm/v/gleastsq)](https://hex.pm/packages/gleastsq)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleastsq/)\n\nA basic least squares fitting library for Gleam. This library uses the [Nx](https://hexdocs.pm/nx/Nx.html) library from Elixir to perform matrix operations.\n\n```sh\ngleam add gleastsq\n```\n\n```gleam\nimport gleam/option.{None}\nimport gleam/list\nimport gleam/io\nimport gleastsq\n\nfn parabola(x: Float, params: List(Float)) -&gt; Float {\n  let assert [a, b, c] = params\n  a *. x *. x +. b *. x +. c\n}\n\npub fn main() {\n  let x = [0.0, 1.0, 2.0, 3.0, 4.0, 5.0]\n  let y = list.map(x, fn(x) { x *. x })\n  let initial_guess = [1.0, 1.0, 1.0]\n\n  let assert Ok(result) =\n    gleastsq.least_squares(\n      x,\n      y,\n      parabola,\n      initial_guess,\n      max_iterations: None,\n      epsilon: None,\n      tolerance: None,\n      lambda_reg: None,\n    )\n\n  io.debug(result) // [1.0, 0.0, 0.0] (within numerical error)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleastsq&gt;.\n","url":"index.html"},{"doc":"gleastsq","title":"FitErrors","content":"pub opaque type FitErrors\n\n\nSynonyms:\ngleastsq.FitErrors\ngleastsq FitErrors","url":"gleastsq.html#FitErrors"},{"doc":"gleastsq","title":"least_squares","content":"pub fn least_squares(\n  x: List(Float),\n  y: List(Float),\n  func: fn(Float, List(Float)) -&gt; Float,\n  initial_params: List(Float),\n  max_iterations iterations: Option(Int),\n  epsilon epsilon: Option(Float),\n  tolerance tolerance: Option(Float),\n  lambda_reg lambda_reg: Option(Float),\n) -&gt; Result(List(Float), FitErrors)\n Compute the least squares fit of a function to a set of data points.\n\n ## Parameters:\n - `x`: The X axis of the data points as a list of floats.\n - `y`: The Y axis of the data points as a list of floats.\n - `func`: The function to fit to the data points. The function should take a float and a list of floats (the function coefficients) as arguments and return a float.\n - `initial_params`: The initial guess for the function coefficients.\n - `max_iterations`: The maximum number of iterations to perform. Default is 100.\n - `epsilon`: The epsilon value for the numerical derivative. Default is 0.0001.\n - `tolerance`: The tolerance for the convergence criterion. Default is 0.0001.\n - `lambda_reg`: The regularization parameter. Default is 0.0001.\n\n ## Examples\n\n \n fn parabola(x: Float, params: List(Float)) -&gt; Float {\n   let assert [a, b, c] = params\n   a *. x *. x +. b *. x +. c\n }\n \n pub fn main() {\n   let x = [0.0, 1.0, 2.0, 3.0, 4.0, 5.0]\n   let y = list.map(x, fn(x) { x *. x })\n   let initial_guess = [1.0, 1.0, 1.0]\n \n   let assert Ok(result) =\n     gleastsq.least_squares(\n       x,\n       y,\n       parabola,\n       initial_guess,\n       max_iterations: None,\n       epsilon: None,\n       tolerance: None,\n       lambda_reg: None,\n     )\n \n   io.debug(result) // [1.0, 0.0, 0.0] (within numerical error)\n }\n \nSynonyms:\ngleastsq.least_squares\ngleastsq least_squares","url":"gleastsq.html#least_squares"},{"doc":"gleastsq","title":"gleastsq","content":"","url":"gleastsq.html"}]);